/*
* common.js
* 自定义函数库
* wei.shi#shouqu.me
*/

//parse url params
var urlParams = {};
(function() {
	var e, 
	a = /\+/g,  // Regex for replacing addition symbol with a space
	r = /([^&=]+)=?([^&]*)/g, 
	d = function(s) {
		return decodeURIComponent(s.replace(a, " "));
	}, 
	q = window.location.search.substring(1);
	
	while (e = r.exec(q))
		urlParams[d(e[1])] = d(e[2]);
})();

/**
* 获取图片原始尺寸
* @params obj, 图像Element对象
* @params callback(res,obj), 回调函数，res:图片尺寸对象，obj:图片本身
*/
function getImgSize(obj,callback){
	var img = new Image();
	img.onload = function(){
		var res = {
			"width" : this.width,
			"height" : this.height
		};
		callback(res,obj);
	};
	img.src = obj.src;
}

/**
* 遍历DOM方法
*/
function traverseDOM (node, func) {
	func(node);
	node = node.firstChild;
	while (node) {
		traverseDOM(node, func);
		node = node.nextSibling;
	}
}

/**
* 获取元素数组by className属性
*/
function gEBCN(clsName){
	return document.getElementsByClassName(clsName);
}

/**
* 通过浏览器判断移动端平台类型
*/
function checkMobile(){
	var isMobile = {
		Android: function() {
			return !!navigator.userAgent.match(/Android/i) ? navigator.userAgent.match(/Android/i) : false;
		},
		BlackBerry: function() {
			return !!navigator.userAgent.match(/BlackBerry/i) ? navigator.userAgent.match(/BlackBerry/i) : false;
		},
		iOS: function() {
			return !!navigator.userAgent.match(/iPhone|iPad|iPod/i) ? navigator.userAgent.match(/iPhone|iPad|iPod/i) :false;
		},
		Opera: function() {
			return !!navigator.userAgent.match(/Opera Mini/i)?navigator.userAgent.match(/Opera Mini/i):false;
		},
		Windows: function() {
			return !!navigator.userAgent.match(/IEMobile/i)?navigator.userAgent.match(/IEMobile/i):false;
		},
		Wechat: function(){
			return !!navigator.userAgent.match(/MicroMessenger/i)?navigator.userAgent.match(/IEMobile/i):false;
		},
		any: function() {
			return (isMobile.Android() || isMobile.BlackBerry() || isMobile.iOS() || isMobile.Opera() || isMobile.Windows() || isMobile.Wechat());
		}
	};
	return isMobile.any();
}

/**
* 通过mediaquery 判断iphone类型
*/
function checkIphone(){
	var type = null;
	//media query
	var MediaQuery = {
		'iphone4':'only screen     and (min-device-width : 320px)    and (max-device-width : 480px)     and (orientation : portrait) 	and (color:8)    and (device-aspect-ratio : 320/480)        and (-webkit-device-pixel-ratio : 2)    and (-webkit-min-device-pixel-ratio : 2)',
		'iphone5':'only screen     and (min-device-width : 320px)    and (max-device-width : 568px)     and (orientation : portrait) 	and (color:8)    and (device-aspect-ratio : 320/568)        and (-webkit-device-pixel-ratio : 2)    and (-webkit-min-device-pixel-ratio : 2)',
		'iphone6':'only screen     and (min-device-width : 375px)    and (max-device-width : 667px)     and (orientation : portrait)     and (color : 8)    and (device-aspect-ratio : 375/667)        and (-webkit-device-pixel-ratio : 2)    and (-webkit-min-device-pixel-ratio : 2)',
		'iphone6plus':'only screen     and (min-device-width : 414px)     and (max-device-width : 736px)    and (device-width : 414px)    and (device-height : 736px)    and (orientation : portrait)     and (-webkit-min-device-pixel-ratio : 3)     and (-webkit-device-pixel-ratio : 3)'
	};
	window.MediaQuery = MediaQuery;
	for(var i in MediaQuery){
		if(window.matchMedia(MediaQuery[i]).matches){
			type = i;
			break;
		}
	}
	return type;
}

/** 
* 用户头像加载失败，加载默认头像图片 
* size 指定尺寸，默认图片为92x92
*/
function loadDefaultAvatar(size){
	var img = event.srcElement; 
	img.src = "https://shouqu.me/images/avatar@2x.png"; 
	img.onerror = null; //避免死循环
}

/*
// Usage:
utoa('✓ à la mode'); // 4pyTIMOgIGxhIG1vZGU=
atou('4pyTIMOgIGxhIG1vZGU='); // "✓ à la mode"

utoa('I \u2661 Unicode!'); // SSDimaEgVW5pY29kZSE=
atou('SSDimaEgVW5pY29kZSE='); // "I ♡ Unicode!"
*/
// ucs-2 string to base64 encoded ascii
function utoa(str) {
    return window.btoa(unescape(encodeURIComponent(str)));
}
// base64 encoded ascii to ucs-2 string
function atou(str) {
    return decodeURIComponent(escape(window.atob(str)));
}

//class name operation
function hasClass(el, className) {
  if (el.classList)
    return el.classList.contains(className)
  else
    return !!el.className.match(new RegExp('(\\s|^)' + className + '(\\s|$)'))
}

function addClass(el, className) {
  if (el.classList)
    el.classList.add(className)
  else if (!hasClass(el, className)) el.className += " " + className
}

function removeClass(el, className) {
  if (el.classList)
    el.classList.remove(className)
  else if (hasClass(el, className)) {
    var reg = new RegExp('(\\s|^)' + className + '(\\s|$)')
    el.className=el.className.replace(reg, ' ')
  }
}

//调整文字大小
//@size:以1为基准
function adjustFontSize(size){
    var clsName = "fs-m";
    var num = parseFloat(size);
    var body = document.getElementsByTagName("body")[0];
    
    //传入非数值参数
    if(isNaN(num)){
        return clsName;
    }
    //根据选择的size值设置特定的类名
    switch (size){
        case 0.85:
            clsName = "fs-s";
            break;
        case 1.1:
            clsName = "fs-l";
            break;
        case 1.2:
            clsName = "fs-xl";
            break;
        case 1.3:
            clsName = "fs-xxl";
            break;
    }
    
    //执行类切换
    removeClass(body,"fs-s");
    removeClass(body,"fs-l");
    removeClass(body,"fs-m");
    removeClass(body,"fs-xl");
    removeClass(body,"fs-xxl");
    addClass(body,clsName);

}

//调整innerdiv文本行高
//@size:以1为基准，原值的倍数
function adjustLineHeight(size){
	//var primary = 1.8;
    var clsName = "lh-m";
    var num = parseFloat(size);
    var body = document.getElementsByTagName("body")[0];
    
    //传入非数值参数
    if(isNaN(num)){
        return clsName;
    }
    //根据选择的size值设置特定的类名
    switch (size){
        case 0.8:
            clsName = "lh-s";
            break;
        case 1.15:
            clsName = "lh-l";
            break;
        case 1.3:
            clsName = "lh-xl";
            break;
        case 1.45:
            clsName = "lh-xxl";
            break;
    }
    
    //执行类切换
    removeClass(body,"lh-s");
    removeClass(body,"lh-l");
    removeClass(body,"lh-m");
    removeClass(body,"lh-xl");
    removeClass(body,"lh-xxl");
    addClass(body,clsName);
    
    
}
//调整innerdiv文本行宽度,实际调整的是两侧边距，算法为原边距×1/倍数
//@size:以1为基准，原值的倍数
function adjustLineWidth(size){
	
	var clsName = "lw-m";//默认中号
    window.mediaLeftMargin = 22;
    window.contentPadding = 22;
	var num = parseFloat(size);
	var body = document.getElementsByTagName("body")[0];
	
	//传入非数值参数
	if(isNaN(num)){
		return clsName;
	}
	//console.log(num);
	//根据选择的size值设置特定的类名
	switch (size){
		case 1.4:
			clsName = "lw-s";
            window.mediaLeftMargin = 12;
            window.contentPadding = 12;
			break;
		case 0.8:
			clsName = "lw-l";
            window.mediaLeftMargin = 28;
            window.contentPadding = 28;
            break;
		case 0.6:
			clsName = "lw-xl";
            window.mediaLeftMargin = 36;
            window.contentPadding = 36;
            break;
		case 0.36:
			clsName = "lw-xxl";
            window.mediaLeftMargin = 60;
            window.contentPadding = 60;
            break;
	}
	
	//执行类切换
	removeClass(body,"lw-s");
	removeClass(body,"lw-l");
	removeClass(body,"lw-m");
	removeClass(body,"lw-xl");
	removeClass(body,"lw-xxl");
	addClass(body,clsName);
    
    //resizeImage()
    
   
	
	/*
	if(size == 0){console.log("错误的参数");return false;}
	var title = document.getElementsByTagName("H1")[0];
	var primary = ( window.screen.width >= 768 )? 72 : 18;
	var val = Math.round(1 / size * primary);
	
	var weiboContentRepotext = document.getElementsByClassName("weibo-content-repotext");
	var blockquotes = document.getElementsByTagName("blockquote");
	//console.log("linewidth:",val);
	
	//改变内容两侧边距
	document.getElementById("innerdiv").style.paddingLeft = val + "px";
	document.getElementById("innerdiv").style.paddingRight = val + "px";
	
	//改变标题两侧边距
	if(title){
		title.style.paddingLeft = val + "px";
		title.style.paddingRight = val + "px";
	}
	
	
	
	//执行以下调整图片代码存在不确定性，需要走重新渲染过程，将大小尺寸图片区分开
	var imgs = document.getElementsByTagName("img");
	
	//设置内容内边距和图片等顶边元素的左边距,还有初始边距，在article.js中需要判断是否存在此全局值
	window.mediaLeftMargin = 0;
	window.contentPadding = val;
	window.primaryPadding = primary;
	
	// if(parseFloat(size) > 1){
		// window.contentPadding = window.primaryPadding;
	// }
	for(var i = 0,len = imgs.length;i < len; i++){
		//imgs[i].style.left = sideMargin + "px";
		//alert("adjustLineWidth")
		resizeImage(imgs[i]);
	}
	for(var i = 0,len = weiboContentRepotext.length; i < len; i++){
		//alert("weiborep"+i)
		var innerPadding = (checkMobile()[0].toLowerCase() == "ipad") ? 72 : 28;
		weiboContentRepotext[i].style.width = ( window.screen.width - contentPadding * 2 - innerPadding) + "px";
		weiboContentRepotext[i].style.left = 0;
		if(parseFloat(size) >= 1){
			
			//weiboContentRepotext[i].style.left = "-" + window.contentPadding + "px";
			if(checkMobile()[0].toLowerCase() != "ipad"){
				weiboContentRepotext[i].style.width = window.screen.width - innerPadding  + "px";
				weiboContentRepotext[i].style.left = "-" + window.contentPadding + "px";
			}
		}
	}*/
    /*
	for(var i = 0,len = blockquotes.length; i < len; i++){
		var innerPadding = (checkMobile()[0].toLowerCase() == "ipad") ? 21 : 22;
		blockquotes[i].style.width = (document.body.clientWidth - val * 2 - innerPadding) + "px";//font-size默认是17像素，blockquote的padding为.5em，所以两侧一共1em=17px;ipad上是16像素，border5像素
		blockquotes[i].style.marginLeft = 0;
		if(parseFloat(size) >= 1){
			
			//blockquotes[i].style.marginLeft = "-" + window.contentPadding + "px";
			if(checkMobile()[0].toLowerCase() != "ipad"){
				blockquotes[i].style.width = document.body.clientWidth - innerPadding  + "px";
				blockquotes[i].style.left = "-" + window.contentPadding + "px";
			}
		}
		
	}
     */
	
}

//调整背景色和前景文字颜色
//@bg_color 默认:default,中亮:mid-light,中暗:mid-dark,暗:dark
function adjustBackgroundColor(bg_color){
	var clsName = "";
	var body = document.querySelector("body");
	bg_color = String(bg_color);
	if(bg_color && bg_color !== "default"){
		clsName = "bg-" + bg_color;
	}
	
	removeClass(body,"bg-qianmi");
	removeClass(body,"bg-danfen");
	removeClass(body,"bg-zhihui");
	removeClass(body,"bg-qingxin");
	removeClass(body,"bg-shenhui");
	
	if(clsName !== ""){
		addClass(body,clsName);
	}
}

//调整字体家族
//@font_name 系统字体:default,楷体:kaiti,仿宋:fangsong,书宋:shusong,思源黑体:heiti,幼圆:youyuan,报宋:baosong
function adjustFontFace(font_name){
	var clsName = "";
	var body = document.querySelector("body");
	if(font_name && font_name !== "default") {
		clsName = "font-" + font_name;
	}
	
	removeClass(body,"font-kaiti");
	removeClass(body,"font-fangsong");
	removeClass(body,"font-shusong");
	removeClass(body,"font-heiti");
	removeClass(body,"font-youyuan");
	removeClass(body,"font-baosong");
	
	
	if(clsName !== ""){
		addClass(body,clsName);
	}
}

//向页面写入字体配置样式
//@str_font_set:JSON序列化字符串形式
//[
//	{font_name:"fangsong",font_url : "fonts/FZFSJW.TTF",font_type:"truetype"},
//	...
// {font_name : "fangsong",font_url : "..."}
//]
function writeFontFace(str_font_set){
	//解析json字符串
	var json;
	try{
		json = JSON.parse(str_font_set);
	}catch(ex){
		console.log("解析参数失败:",ex.name ,ex.message);
		return false;
	}
	
	//设置element id
	var styleElementId = "sq_font_face";
	var elementStyle = document.getElementById(styleElementId);
	
	//enhance map param name to css font family name
	json.forEach(function(ele,idx,arr){
		//设置font-family name
		switch(ele.font_name){
			case "fangsong":
				//ele.font_name = "FZFangsong";
				ele.font_name = "HWFangsong";
				break;
			case "shusong":
				ele.font_name = "FZShusong";
				break;
			case "heiti":
				ele.font_name = "SYheiti";
				break;
			case "kaiti":
				//ele.font_name = "FZKaiti";
				ele.font_name = "HWKaiti";
				break;
			case "baosong":
				ele.font_name = "FZBaosong";
				break;
			case "youyuan":
				ele.font_name = "Youyuan";
				break;
		}
		var filetype = ele.font_url.substring(ele.font_url.lastIndexOf(".")+1).toLowerCase();
		switch(filetype){
			case "ttf":
				ele.font_type = "truetype";
				break;
			case "otf":
				ele.font_type = "opentype";
				break;
		}
		
	})
	
	//解析font-face,空数组返回空字符串结果
	var css_text = 	json.map(function(ele){
		return '\
		@font-face{ \
			font-family:"'+ ele.font_name +'";\
			src : url('+ ele.font_url +') format("'+ ele.font_type +'");\
			font-style:normal;\
			font-weight:normal;\
		}\
		'
	}).join("");
	
	
	//添加新的style标签
	if(!elementStyle){
		elementStyle = document.createElement('style');
		elementStyle.type = "text/css";
		elementStyle.id = styleElementId;
		document.getElementsByTagName('head')[0].appendChild(elementStyle);
	}
	
	//更新内容
	elementStyle.innerText = css_text;
	
}

//调整图片至屏幕宽度，排除某些页面和比例的图片
function resizeImage(objImage,contentPadding,sideMargin){
	if($('body').attr('id') == 'nobar' || objImage.src.match(/shouqu.com/g) != null){
		return true;
	}
	
	//排除微博模板中的头像 //2016-11-2
	if($("body").hasClass("weibo") && $(objImage).hasClass("weibo-profile-avatar")
		|| $("body").hasClass("video") && $(objImage).hasClass("avatar")// 视频页面头像，例子：小咔秀
	){
		return false;
	}
	
	//排除页脚底部的图片
	if(objImage.id == "footer-line"){
		return false;
	}
	//alert(objImage)
	
	//判断图片的原始大小，是否满足放大的要求
	getImgSize(objImage,function(res,obj){
		//console.log(res,obj)

		//get device type and name
		var device = checkMobile();
		var iphone_type = checkIphone();

		//如果图像原始宽度与屏幕宽度差小于某个数值，则强制放大至与屏幕宽度相同
		var diff = window.screen.width - res.width;
		var min = window.primaryPadding || (window.screen.width >= 768 ? 72 : 14);//测试宽度差值，可实时调整
		var ratio = res.width / window.screen.width;

		var imgComputedStyle = getComputedStyle(obj,null);
		var imgAttributes = obj.attributes;
		var width_attr_name = /width|_width|original-width/g; //原文可能用来设置图片宽度的属性值正则，如果没有可以添加
		
		//obj_width默认为图片原始大小，如果原始图片中存在硬性属性设置，则依据其原始设置判断
		var obj_width = res.width;
		for(var i = 0,len = imgAttributes.length;i < len; i++){
			if(imgAttributes[i].name.match(width_attr_name)){
				//如果属性意图不比原始图片大，则采用属性意图
				if( parseInt(obj.getAttribute(imgAttributes[i].name)) < obj_width ){
					obj_width = parseInt(obj.getAttribute(imgAttributes[i].name));
				}
				//如果样式意图不比属性意图或者原始尺寸大，则采用样式意图
				if( parseInt(imgComputedStyle.width) < obj_width ){
					obj_width = parseInt(imgComputedStyle.width)
				}
				//console.log("obj_width:",obj_width);
			}
		}
		
		diff = obj_width < window.screen.width ? Math.abs(window.screen.width - obj_width) : 0;
		ratio = obj_width / window.screen.width;
		
		//小屏幕设置图片与屏幕等宽
		if(
			( (window.screen.width < 414 && ratio > 0.4) || (window.screen.width == 414 && ratio > 0.36) ) || diff < min
		){
			//正常
			obj.style.width = window.screen.width + "px";
			obj.style.left =  "-" + min + "px";
			
			if(window.contentPadding && window.contentPadding > min){//边距比初始边距小时
				obj.style.left = 0;
				obj.style.width = window.screen.width - 2 * window.contentPadding + "px";
			}
			
			//边距比初始尺寸大时
			if(window.contentPadding && window.contentPadding < min){
				obj.style.left =  "-" + window.contentPadding + "px";
			}
	
		}
		
		//ipad 及屏幕大于768的
		if( window.screen.width >= 768 && ratio > 0.6){
			obj.style.width = 624 + "px";
			obj.style.maxWidth = 624 + "px";
			obj.style.left = 0;
			
			if(window.contentPadding ){//如果存在边距调整要求则调整图片宽度
				obj.style.width = window.screen.width - 2 * window.contentPadding + "px";
				obj.style.maxWidth = window.screen.width - 2 * window.contentPadding + "px";
			}
			
			
		}
		
		//新浪微博小图标重新处理
		if(obj.src.match(/timeline_card_small_[a-z]+_default/g) != null ){
			//console.log("sinaweibo");
			obj.style.width = '1em';
			obj.style.position = 'relative';
			obj.style.left = '4px';
			obj.style.verticalAlign = 'bottom';
		}else{
			////console.log('should autocenter');
			$(obj).addClass('autocenter');
		}
		
	});


}

//////////////////////笔记相关暴露给原生调用的全局函数////////////////////

//清除选中区域
function clearSelection(){
	var selection = window.getSelection();
	if(selection.anchorNode != null || selection.focusNode != null || (selection.type != null && selection.type.toLowerCase() != "none")){
		selection.collapseToStart();
		selection.removeAllRanges();
	}
}

//加载指定数据的笔记数据
function js_loadNoteData(data){
	//alert(JSON.stringify(data));
	//console.log("loading data",data);
	if(typeof data == "undefined"){
		console.log("数据值为空");
		return false;
	}
	if(typeof data != 'object'){
		console.log("数据格式有误");
		return false;
	}
	try{

		
		
		//console.log("加载高亮数据...", data);

		//把回车转义替换为json兼容格式
		//data = data.replace(/\n/g,"\\n");
		//data = data.replace(/'/g,"\\'");
		/*
		data = data.replace(/\n|'/g,function(k){
			if( k.match(/\n/) ){
				return "\\n";
			}else if( k == "'" ){
				return "\\\\'";
			}
		});
		*/
		
		//如果有数据且没有版本号||有数据且版本号为1，则认为是旧版本数据
		//否则就是没有数据或者有数据且有版本号不为1
		//data不一定为null，具体值需要与app协商,app端需要传一个明确的值data.dataVersion为1或者2
		if(data!= null && ( typeof data.dataVersion == "undefined" || data.dataVersion == 1) ){
			MarkUtil.setDataFormatVersion(1);
			MarkUtil.formatTextNodes(1);
		}else{
			MarkUtil.setDataFormatVersion(2);
			MarkUtil.formatTextNodes(2);
		}
		
		//data本身是json object对象
		var noteData = data;
		window.currentNoteData = noteData;


		//window.bookmarkID = noteData.bookmarkID;//window存入bookmarkID
		//window.maxNoteIndex = bookmarkID + "_" + 1; //默认初始最大bookmark ID 为bookmarkID_1

		//notes数据不为空时才执行高亮标记
		if(noteData.notes && noteData.notes.length > 0){

			//根据已有notes数据计算最大可用noteIndex
			//var maxNoteTime = _.max(noteData.notes,function(o){return o.createTime});

			//需要根据note创建时间升序排序，然后依次在dom上标记高亮效果
			var sorted_notes = _.sortBy(noteData.notes,'createTime');
			noteData.notes = sorted_notes;

			MarkUtil.loadMarkData(noteData);
			//MarkUtil.loadMarkData(noteData);

			//根据note数据依次加高亮效果，并在每次高亮后，处理好起止节点未包括在高亮内的文字，将他们也包裹在sqt标签内，以保证下一次获取sqt 序号的正确性
		}

		//MarkUtil.loadMarkData(window.currentNoteData);

		//清除选中区域
		clearSelection();


	}catch(er){
		console.log(er.name + ":" + er.message);
		if(navigator.userAgent.match(/iPhone|iPad|iPod/i) == null && er.name.match(/IndexSizeError/ig) != null){
							console.log(data)
							//js_loadNoteData(data);
						}
	}

}

//highlight text and generate the selections data
function js_highlightNote(){

	//just for test 
	//console.log(typeof window.note);
	
	var selection = window.getSelection();

	if(selection.type.toLowerCase() == "none"){
		console.log("错误：没有选中任何区域");
	}else{
		//选区数据数组
		var selectionData;
		if(MarkUtil.dataFormatVersion == 1){
			selectionData = MarkUtil.getSelectionData(selection);
		}else if(MarkUtil.dataFormatVersion == 2){
			selectionData = MarkUtil.getSelectionDataV2(selection);
		}

		//保存到全局数据，供高亮回调函数使用
		window.selections = selectionData;

		//用于传给native的高亮数据对象
		var noteData = {
			selections : window.selections,
			highlightText : selection.toString(),
			dataVersion : MarkUtil.dataFormatVersion //增加数据格式版本字段
		};

		////console.log("发送给native保存...");
		try{
			if(typeof window.note != "undefined" && typeof window.note.native_saveNoteData != "undefined"){
				window.note.native_saveNoteData(JSON.stringify(noteData));
			}else{
				native_saveNoteData(noteData);
			}
		}catch(exception){
			console.log(exception.name + " : " + exception.message);
		}
	}

}

//native highlight callback
function js_highlightNoteCallback(noteID){
	if(typeof noteID == "number"){
		alert("传入的noteID为数字");
		return false;
	}
	//console.log("传入的noteID:",noteID);
	if(typeof(noteID) != "undefined"){

		//组合高亮数据对象
		var noteData = {
			noteID : noteID+"",//强制转换为字符串型
			selections : window.selections,
			createTime: _.now()//js生成的时间戳，实际应用应当是app端生成并存入数据库
		};

		//用于MarkUtil.addMarks的参数是一个数组

		var notes = [noteData];
		//console.log("高亮回调：",noteData);

		//just for test
		// var note = {
		    // userId:"emulator",
		    // bookmarkId:"jidowkdi23432",
		    // notes:notes
		// };
		//console.log(JSON.stringify(note));

		// if(window.notes){
			// window.notes.push(noteData);
		// }

		//载入高亮数据
		MarkUtil.addMarks(notes);

		//clearSelection();

		//通知native加载
		try{
			if(typeof window.note != "undefined" && typeof window.note.native_reload != "undefined"){
				window.note.native_reload();
			}else if(typeof native_reload != "undefined"){
				native_reload();
			}
		}catch(exception){
			console.log(exception.name + " : " + exception.message);
		}

	}

}

//添加注释按钮
function js_addComment(noteID){

	if(typeof(noteID) != "undefined"){

		//拿到指定noteID的那部分高亮，给最后一个后面加上注释按钮
		var $note = $("." + MarkUtil.activeClassName + "[data-noteid='" + noteID + "']");
		if($note.last().next(".comment-icon").length == 0 ){

			$note.last().after('<i class="comment-icon" data-noteid="'+ noteID +'"><b>...</b></i>');

		}

	}else{

		//console.log("没有传入noteID");

	}

}

//删除高亮按钮并恢复原节点内容
function js_deleteNote(noteID){

	if(typeof(noteID) != "undefined"){

		//按noteID删除注释按钮
		//需要先删除注释按钮，否则已高亮部分会将按钮中的点作为文本加入到原先的文本中
		js_deleteComment(noteID);

		//高亮文本使用了<span class="mark-text">xxx</span>来标记文字，其父元素是span.MarkUtil.markSpanClassName
		//因此将父元素的html内容（包括未被高亮的文字部分）替换成其整个文本内容即可
		var $note = $("." + MarkUtil.activeClassName + "[data-noteid='" + noteID + "']");
		$note.each(function(i,v){
			//console.log(i);
			//$(v).removeClass(MarkUtil.activeClassName).removeAttr('data-noteid');
			var text = v.parentElement.innerText;
			var textNode = document.createTextNode(text);

			$(v.parentElement).empty().append(textNode);
		});

		//console.log("delete note done");

		//让选中区域消失
		js_collapseSelection();

		//通知native加载，上线版本中已关闭此命令
		//native_reload();

	}else{
		//console.log("没有传入noteID");
	}

}

//删除注释按钮
function js_deleteComment(noteID,commentID){

	if(typeof(noteID) != "undefined"){

		//使用jquery的remove方法将注释按钮删除
		$(".comment-icon[data-noteid='" + noteID + "']").remove();

		//通知native加载
		try{
			if(typeof window.note != "undefined" && typeof window.note.native_reload != "undefined" ){
				window.note.native_reload();
			}else if(typeof native_reload != "undefined"){
				native_reload();
			}
		}catch(exception){
			console.log(exception.name + " : " + exception.message);
		}

	}else{
		//console.log("没有传入noteID");
	}

}

//利用remove all ranges清除所有选中的文字
function js_collapseSelection(){

	var selection = window.getSelection();
	selection.removeAllRanges();

}

//获取选中部分文字
function js_getSelectionText(){
	var selection = window.getSelection();
	if(selection.type.toLowerCase() != "none"){
		return selection.toString();
	}
}

//书签页打开时跳转至指定ID元素所在位置
function scrollToElementByID(strElementID){

	//过滤空值参数
	if(typeof strElementID == "undefined"){
		console.log("错误：没有传入元素ID");
		return false;
	}

	//初始化高亮标记CSS类名，如果存在MarkUtil则使用MarkUtil中定义的类名
	var activeClassName = "mark-text";
	if(MarkUtil && MarkUtil.activeClassName){
		activeClassName = MarkUtil.activeClassName;
	}

	//根据ID属性或data-noteid属性获得元素
	var ele = document.getElementById(strElementID) == null ? document.querySelectorAll("." + MarkUtil.activeClassName + "[data-noteid='"+ strElementID +"']")[0] : document.getElementById(strElementID);

	//滚动到元素所在坐标
	window.scrollTo(ele.offsetLeft, ele.offsetTop);

}

//给body代理绑定高亮和注释按钮touchend事件，用mark-text和comment-icon两个类名称区分展示高亮或评论菜单
//并向navite传入用户点击的屏幕位置信息
function commentEventHandler(e){

	var screenx = e.changedTouches[0].clientX;
	var screeny = e.changedTouches[0].clientY;
	/*
	if(e.target.className != "" && e.target.className.match(/mark-text/)){
		var noteID = $(e.target).attr("data-noteid");
		////console.log(screenx,screeny,noteID);
		native_popMenushowWithLocation(screenx,screeny,noteID);

	}else*/ if( (e.target.className != "" && e.target.className.match(/comment-icon/) ) || ( e.target.tagName.toLowerCase() == "b" && e.target.parentElement.className.match(/comment-icon/) ) ){

		//获取点击对象的noteID,如果点击的是b标签则从其父元素获取noteID
		var noteID = $(e.target).attr("data-noteid");
		if(typeof noteID == "undefined"){
			noteID = $(e.target).parent(".comment-icon").attr("data-noteid");
		}

		//native_displayCommentMenu(screenx,screeny,noteID);
		try{
			if(typeof window.note != "undefined" && typeof window.note.native_displayCommentMenu != "undefined"){
				window.note.native_displayCommentMenu(screenx,screeny,noteID);;
			}else{
				native_displayCommentMenu(screenx,screeny,noteID);;
			}
		}catch(exception){
			//console.log(exception.name + " : " + exception.message);
		}

	}else{
		return false;
	}
}


//....////////////////////笔记相关暴露给原生调用的全局函数/////////////....///


